@@ -226,10 +226,12 @@ async function validateObjectId(item, models, pushError) {
 
 export async function permissionLoader(item, { models, pushError }) {
   const { verb, noun, objectId = null, ...roles } = stripNotes(item);
-
+  
   const normalizedObjectId = objectId && objectId.trim() !== '' ? objectId : null;
-
-  await validateObjectId({ ...item, objectId: normalizedObjectId }, models, pushError);
+  const normalizedVerb = verb.trim();
+  const normalizedNoun = noun.trim();
+  
+  await validateObjectId({ ...item, noun: normalizedNoun, objectId: normalizedObjectId }, models, pushError);
 
   // Any non-empty value in the role cell would mean the role
   // is enabled for the permission
@@ -237,7 +239,7 @@ export async function permissionLoader(item, { models, pushError }) {
     .map(([role, yCell]) => [role, yCell.toLowerCase().trim()])
     .filter(([, yCell]) => yCell)
     .map(([role, yCell]) => {
-      const id = `${role}-${verb}-${noun}-${normalizedObjectId || 'any'}`.toLowerCase();
+      const id = `${role}-${normalizedVerb}-${normalizedNoun}-${normalizedObjectId || 'any'}`.toLowerCase();
 
       const isDeleted = yCell === 'n';
       const deletedAt = isDeleted ? new Date() : null;
@@ -247,8 +249,8 @@ export async function permissionLoader(item, { models, pushError }) {
         values: {
           _yCell: yCell,
           id,
-          verb,
-          noun,
+          verb: normalizedVerb,
+          noun: normalizedNoun,
           objectId: normalizedObjectId,
           role,
           deletedAt,
