@@ -1,6 +1,6 @@
 import { utils } from 'xlsx';
 
-import { PATIENT_FIELD_DEFINITION_TYPES, REFERENCE_TYPE_VALUES } from '@tamanu/constants';
+import { REFERENCE_TYPE_VALUES } from '@tamanu/constants';
 import { DataLoaderError, ValidationError, WorkSheetError } from '../errors';
 import { statkey, updateStat } from '../stats';
 import { importRows } from '../importer/importRows';
@@ -78,7 +78,10 @@ const FOREIGN_KEY_SCHEMATA = {
   ],
 };
 
-export async function importSheet({ errors, log, models }, { loader, sheetName, sheet }) {
+export async function importSheet(
+  { errors, log, models },
+  { loader, sheetName, sheet, skipExisting },
+) {
   const stats = {};
 
   log.debug('Loading rows from sheet');
@@ -104,37 +107,18 @@ export async function importSheet({ errors, log, models }, { loader, sheetName,
       Object.entries(data).map(([key, value]) => [key.trim(), value]),
     );
     try {
-      for (const { model, values } of await loader(trimmed, models, FOREIGN_KEY_SCHEMATA)) {
+      for (const { model, values } of await loader(trimmed, {
+        models,
+        foreignKeySchemata: FOREIGN_KEY_SCHEMATA,
+        pushError: message => errors.push(new ValidationError(sheetName, sheetRow, message)),
+      })) {
         if (!models[model]) throw new Error(`No such type of data: ${model}`);
-        if (model === 'PatientFieldValue') {
-          const existingDefinition =
-            values?.definitionId &&
-            (await models.PatientFieldDefinition.findOne({ where: { id: values.definitionId } }));
-          if (!existingDefinition)
-            throw new Error(`No such patient field definition: ${values?.definitionId}`);
-          if (
-            existingDefinition.fieldType === PATIENT_FIELD_DEFINITION_TYPES.NUMBER &&
-            values.value &&
-            isNaN(values.value)
-          )
-            throw new Error(`Field Type mismatch: expected field type is a number value`);
-          if (
-            existingDefinition.fieldType === PATIENT_FIELD_DEFINITION_TYPES.SELECT &&
-            values.value &&
-            !existingDefinition.options.includes(values.value)
-          )
-            throw new Error(
-              `Field Type mismatch: expected value to be one of "${existingDefinition.options.join(
-                ', ',
-              )}"`,
-            );
-        }
 
-        if (values.id && idCache.has(values.id)) {
+        if (values.id && idCache.has(`${model}|${values.id}`)) {
           errors.push(new ValidationError(sheetName, sheetRow, `duplicate id: ${values.id}`));
           continue;
         } else {
-          idCache.add(values.id);
+          idCache.add(`${model}|${values.id}`);
         }
 
         updateStat(stats, statkey(model, sheetName), 'created', 0);
@@ -147,7 +131,7 @@ export async function importSheet({ errors, log, models }, { loader, sheetName,
 
   await importRows(
     { errors, log, models },
-    { rows: tableRows, sheetName, stats, foreignKeySchemata: FOREIGN_KEY_SCHEMATA },
+    { rows: tableRows, sheetName, stats, foreignKeySchemata: FOREIGN_KEY_SCHEMATA, skipExisting },
   );
 
   return stats;
